==> tencentcloud-sdk-java-3.1.86-sources.jar: com/tencentcloudapi/cws/v20180312/models/MiniSite.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cws.v20180312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class MiniSite extends AbstractModel{

    /**
    * 站点ID。
    */
    @SerializedName("SiteId")
    @Expose
    private Long SiteId;

    /**
    * 站点Url。
    */
    @SerializedName("Url")
    @Expose
    private String Url;

    /**
     * Get 站点ID。 
     * @return SiteId 站点ID。
     */
    public Long getSiteId() {
        return this.SiteId;
    }

    /**
     * Set 站点ID。
     * @param SiteId 站点ID。
     */
    public void setSiteId(Long SiteId) {
        this.SiteId = SiteId;
    }

    /**
     * Get 站点Url。 
     * @return Url 站点Url。
     */
    public String getUrl() {
        return this.Url;
    }

    /**
     * Set 站点Url。
     * @param Url 站点Url。
     */
    public void setUrl(String Url) {
        this.Url = Url;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "SiteId", this.SiteId);
        this.setParamSimple(map, prefix + "Url", this.Url);

    }
}

==> tencentcloud-sdk-java-3.1.268-sources.jar: com/tencentcloudapi/cws/v20180312/models/MiniSite.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cws.v20180312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class MiniSite extends AbstractModel{

    /**
    * 站点ID。
    */
    @SerializedName("SiteId")
    @Expose
    private Long SiteId;

    /**
    * 站点Url。
    */
    @SerializedName("Url")
    @Expose
    private String Url;

    /**
     * Get 站点ID。 
     * @return SiteId 站点ID。
     */
    public Long getSiteId() {
        return this.SiteId;
    }

    /**
     * Set 站点ID。
     * @param SiteId 站点ID。
     */
    public void setSiteId(Long SiteId) {
        this.SiteId = SiteId;
    }

    /**
     * Get 站点Url。 
     * @return Url 站点Url。
     */
    public String getUrl() {
        return this.Url;
    }

    /**
     * Set 站点Url。
     * @param Url 站点Url。
     */
    public void setUrl(String Url) {
        this.Url = Url;
    }

    public MiniSite() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public MiniSite(MiniSite source) {
        if (source.SiteId != null) {
            this.SiteId = new Long(source.SiteId);
        }
        if (source.Url != null) {
            this.Url = new String(source.Url);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "SiteId", this.SiteId);
        this.setParamSimple(map, prefix + "Url", this.Url);

    }
}
